/**
 * SHProductVO 虾皮商品
 */
export interface SHProductVO {
    /**
     * 品牌id(类目属性冗余过来，这个必填)
     */
    brandId: number;
    /**
     * 类目id
     */
    catePubId: string;
    /**
     * 类目名称
     */
    catePubName: string;
    /**
     * 项目状况，可以是新的或二手的
     */
    conditionVal?: string;
    /**
     * 创建时间
     */
    createTime: Date;
    /**
     * 保证发货订单的天数
     */
    daysToShip?: number;
    /**
     * 是否删除 0:未删除 1:删除
     */
    deleted: boolean;
    /**
     * 描述-需要确认大小
     */
    description: string;
    /**
     * description_type（正常，扩展）--- 不要了，白名单卖家字段关联，那个先不管
     */
    descriptionType?: string;
    /**
     * 虾皮折扣活动ID
     */
    discountId?: number;
    /**
     * (仅适用于 BR 本地卖家）全球贸易项目代码。如果已上传，请通过get_item_base_info api 检查项目的gtin_code
     */
    gtinCode?: string;
    /**
     * 自增id
     */
    id: number;
    /**
     * 图片
     */
    imgUrl: string;
    /**
     * 产品备货数量
     */
    inventory?: number;
    /**
     * 商品是否为预购商品(0.否  1.是)
     */
    isPreOrder: number;
    /**
     * 是否已刊登到店铺1: 是, 2: 否 3.仍需手动重新刊登
     */
    isPublish: string;
    /**
     * 此字段仅适用于印度尼西亚和马来西亚的本地卖家。使用此字段可确定产品是否为危险产品。0 表示非危险品，1 表示危险品。有关更多信息，请访问市场相应的卖家教育中心。)
     */
    itemDangerous?: string;
    /**
     * 产品id
     */
    itemId?: number;
    /**
     * 产品名称
     */
    itemName: string;
    /**
     * 产品状态(UNLIST:下架状态； NORMAL:上架状态)
     */
    itemStatus?: string;
    /**
     * 产品价格
     */
    originalPrice?: number;
    /**
     * 单价折扣
     */
    priceDiscount?: number;
    /**
     * 刊登失败原因
     */
    publishErrInfo?: string;
    /**
     * 刊登时间
     */
    publishTime?: Date;
    /**
     * 用于错误跟踪的 API 请求的标识符
     */
    requestId?: string;
    /**
     * 店铺id
     */
    shopId: number;
    /**
     * 尺码ID
     */
    sizeId?: number;
    /**
     * 产品spu编码
     */
    spuCode: string;
    /**
     * 成品spuCode
     */
    tbSpuCodes: string[];
    /**
     * 模版Id
     */
    templateId: number;
    /**
     * 模版名称
     */
    templateName: string;
}


export interface SHProductPageReqVO extends PageParam {
    /**
     * 品牌id(类目属性冗余过来，这个必填)
     */
    brandId?: number;
    /**
     * 类目id
     */
    catePubId?: string;
    /**
     * 项目状况，可以是新的或二手的
     */
    conditionVal?: string;
    /**
     * 创建时间
     */
    createTime?: string[];
    /**
     * 保证发货订单的天数
     */
    daysToShip?: number;
    /**
     * 描述-需要确认大小
     */
    description?: string;
    /**
     * description_type（正常，扩展）--- 不要了，白名单卖家字段关联，那个先不管
     */
    descriptionType?: string;
    /**
     * 虾皮折扣活动ID
     */
    discountId?: number;
    /**
     * (仅适用于 BR 本地卖家）全球贸易项目代码。如果已上传，请通过get_item_base_info api 检查项目的gtin_code
     */
    gtinCode?: string;
    /**
     * 产品备货数量
     */
    inventory?: number;
    /**
     * 商品是否为预购商品(0.否  1.是)
     */
    isPreOrder?: number;
    /**
     * 是否已刊登到店铺1: 是, 2: 否 3.仍需手动重新刊登
     */
    isPublish?: string;
    /**
     * 此字段仅适用于印度尼西亚和马来西亚的本地卖家。使用此字段可确定产品是否为危险产品。0 表示非危险品，1 表示危险品。有关更多信息，请访问市场相应的卖家教育中心。)
     */
    itemDangerous?: string;
    /**
     * 产品id
     */
    itemId?: number;
    /**
     * 产品名称
     */
    itemName?: string;
    /**
     * 产品状态(UNLIST:下架状态； NORMAL:上架状态)
     */
    itemStatus?: string;
    /**
     * 产品价格
     */
    originalPrice?: number;
    /**
     * 单价折扣
     */
    priceDiscount?: number;
    /**
     * 刊登失败原因
     */
    publishErrInfo?: string;
    /**
     * 刊登时间
     */
    publishTime?: string[];
    /**
     * 用于错误跟踪的 API 请求的标识符
     */
    requestId?: string;
    /**
     * 店铺id
     */
    shopId?: number;
    /**
     * 尺码ID
     */
    sizeId?: number;
    /**
     * 产品spu编码
     */
    spuCode?: string;
    /**
     * 模版Id
     */
    templateId?: number;
}

export interface UpdateSHProductNameReqVO {
    id: number;
    spuCode: string;
    gpts: ProductKeywordGpt[];
}

export interface ProductKeywordGpt {
    id: number;
    keyword: string;
    keywordType: number;
}

export interface UpdateSHProductPriceReqVO {
    id: number;
    originalPrice: number;
}


export interface UpdateSHProductDescReqVO {
    id: number;
    description: string;
}
