import request from '@/request';
import { User, UserVO, UserPageReqVO, UserExportReqVO, PageData } from '@/models';

const BASE_URL = '/admin-api/system/user';

export default {

    getProfile: () => {
        return request.get<User>(`${BASE_URL}/profile/get`)
    },

    // 查询用户管理列表
    getUserPageApi: (params: UserPageReqVO) => {
        return request.get<PageData<UserVO>>(`${BASE_URL}/page`, { params })
    },

    // 查询用户详情
    getUserApi: (id: number) => {
        return request.get(`${BASE_URL}/get?id=` + id)
    },

    // 新增用户
    createUserApi: (data: UserVO) => {
        return request.post(`${BASE_URL}/create`, data)
    },

    // 修改用户
    updateUserApi: (data: UserVO) => {
        return request.put(`${BASE_URL}/update`, data)
    },

    // 删除用户
    deleteUserApi: (id: number) => {
        return request.delete(`${BASE_URL}/delete?id=` + id)
    },

    // 导出用户
    exportUserApi: (params: UserExportReqVO) => {
        return request.get(`${BASE_URL}/export`, { params, responseType: 'blob' })
    },

    // 下载用户导入模板
    importUserTemplateApi: () => {
        return request.get(`${BASE_URL}/get-import-template`, { responseType: 'blob' })
    },

    // 用户密码重置
    resetUserPwdApi: (id: number, password: string) => {
        const data = {
            id,
            password
        }
        return request.put(`${BASE_URL}/update-password`, data)
    },

    // 用户状态修改
    updateUserStatusApi: (id: number, status: number) => {
        const data = {
            id,
            status
        }
        return request.put(`${BASE_URL}/update-status`, data)
    },

    // 获取用户精简信息列表
    getListSimpleUsersApi: () => {
        return request.get(`${BASE_URL}/list-all-simple`)
    },

};
